Index: trunk/BNC/CHANGELOG.md
===================================================================
--- trunk/BNC/CHANGELOG.md	(revision 10618)
+++ trunk/BNC/CHANGELOG.md	(revision 10619)
@@ -1,4 +1,5 @@
 # Changelog
 ## 2.13.2 (2025-02-
+- FIXED: BUG in reading the RTNET format
 - FIXED: Bug in writing code biases into a SSR file
 - FIXED: Bug in GLO ephemeris RTCM3 encoder
@@ -15,4 +16,5 @@
 - CHANGED: Obsolete qt-class members are replaced
 - CHNAGED: from common receiver clock + ISBs to system specific receiver clocks in PPP mode
+- CHANGED: IRNSS replaced by NavIC
 
 ## 2.13.1 (2024-04-30)
Index: trunk/BNC/src/GPSDecoder.h
===================================================================
--- trunk/BNC/src/GPSDecoder.h	(revision 10618)
+++ trunk/BNC/src/GPSDecoder.h	(revision 10619)
@@ -100,5 +100,5 @@
   QList<t_recInfo>        _recType;            // RTCM receiver descriptor
   QList<t_antRefPoint>    _antList;            // RTCM antenna XYZ
-  QList<t_helmertPar>     _helmertPar;     // List of Helmert parameter sets
+  QList<t_helmertPar>     _helmertPar;         // List of Helmert parameter sets
   QList<t_serviceCrs>     _serviceCrs;         // Service CRS
   QList<t_rtcmCrs>        _rtcmCrs;            // RTCM CRS
Index: trunk/BNC/src/RTCM3/RTCM3Decoder.h
===================================================================
--- trunk/BNC/src/RTCM3/RTCM3Decoder.h	(revision 10618)
+++ trunk/BNC/src/RTCM3/RTCM3Decoder.h	(revision 10619)
@@ -138,5 +138,5 @@
    * @return <code>true</code> when data block was decodable
    */
-  bool DecodeIRNSSEphemeris(unsigned char* buffer, int bufLen);
+  bool DecodeNavICEphemeris(unsigned char* buffer, int bufLen);
   /**
    * Extract ephemeris data from 1045 and 1046 RTCM3 messages.
Index: trunk/BNC/src/RTCM3/ephEncoder.cpp
===================================================================
--- trunk/BNC/src/RTCM3/ephEncoder.cpp	(revision 10618)
+++ trunk/BNC/src/RTCM3/ephEncoder.cpp	(revision 10619)
@@ -52,5 +52,5 @@
     GPSADDBITS(1, fitIntervalFlag)
     GPSADDBITS(3, 0) /* padding */
-  } else if (eph.system() == t_eph::IRNSS) {
+  } else if (eph.system() == t_eph::NavIC) {
     GPSADDBITS(12, 1041)
     GPSADDBITS(6, eph._prn.number())
Index: trunk/BNC/src/RTCM3/gnss.h
===================================================================
--- trunk/BNC/src/RTCM3/gnss.h	(revision 10618)
+++ trunk/BNC/src/RTCM3/gnss.h	(revision 10619)
@@ -82,10 +82,10 @@
 #define BDS_WAVELENGTH_B2b  (LIGHTSPEED / BDS_FREQU_B2b) /* m */
 
-#define IRNSS_FREQU_L1      1575420000.0 /* Hz */
-#define IRNSS_FREQU_L5      1176450000.0 /* Hz */
-#define IRNSS_FREQU_S       2492028000.0 /* Hz */
-#define IRNSS_WAVELENGTH_L1 (LIGHTSPEED / IRNSS_FREQU_L1) /* m */
-#define IRNSS_WAVELENGTH_L5 (LIGHTSPEED / IRNSS_FREQU_L5) /* m */
-#define IRNSS_WAVELENGTH_S  (LIGHTSPEED / IRNSS_FREQU_S)  /* m */
+#define NavIC_FREQU_L1      1575420000.0 /* Hz */
+#define NavIC_FREQU_L5      1176450000.0 /* Hz */
+#define NavIC_FREQU_S       2492028000.0 /* Hz */
+#define NavIC_WAVELENGTH_L1 (LIGHTSPEED / NavIC_FREQU_L1) /* m */
+#define NavIC_WAVELENGTH_L5 (LIGHTSPEED / NavIC_FREQU_L5) /* m */
+#define NavIC_WAVELENGTH_S  (LIGHTSPEED / NavIC_FREQU_S)  /* m */
 
 #define R2R_PI          3.1415926535898
Index: trunk/BNC/src/bncantex.cpp
===================================================================
--- trunk/BNC/src/bncantex.cpp	(revision 10618)
+++ trunk/BNC/src/bncantex.cpp	(revision 10619)
@@ -189,5 +189,5 @@
             line.indexOf("BEIDOU") == 0 ||
             line.indexOf("GALILEO") == 0 ||
-            line.indexOf("IRNSS") == 0 ){
+            line.indexOf("NavIC") == 0 ){
           newAntMap->antName = line.mid(20,3);
         }
Index: trunk/BNC/src/bncconst.cpp
===================================================================
--- trunk/BNC/src/bncconst.cpp	(revision 10618)
+++ trunk/BNC/src/bncconst.cpp	(revision 10619)
@@ -66,5 +66,5 @@
   case t_frequency::C8:    return 1191795000.0;
   case t_frequency::C6:    return 1268520000.0;
-  // IRNSS
+  // NavIC
   case t_frequency::I5:    return 1176450000.0;
   case t_frequency::I9:    return 2492028000.0;
Index: trunk/BNC/src/bncconst.h
===================================================================
--- trunk/BNC/src/bncconst.h	(revision 10618)
+++ trunk/BNC/src/bncconst.h	(revision 10619)
@@ -61,5 +61,5 @@
             C8, // B2(B2a+B2b) / 1191.795 (BDS-3 signals)
             C6, // B3,B3A / 1268.52
-            // IRNSS
+            // NavIC
             I5, // L5 / 1176.45
             I9, // S  / 2492.028
@@ -98,5 +98,5 @@
     else if (tt == C8) return "C8";
     else if (tt == C6) return "C6";
-    // IRNSS
+    // NavIC
     else if (tt == I5) return "I5";
     else if (tt == I9) return "I9";
@@ -133,5 +133,5 @@
     else if (s == "C8") return C8;
     else if (s == "C6") return C6;
-    // IRNSS
+    // NavIC
     else if (s == "I5") return I5;
     else if (s == "I9") return I9;
Index: trunk/BNC/src/bncephuser.cpp
===================================================================
--- trunk/BNC/src/bncephuser.cpp	(revision 10618)
+++ trunk/BNC/src/bncephuser.cpp	(revision 10619)
@@ -306,9 +306,9 @@
     }
     // update interval: up to 24 hours
-    else if  (eph->system() == t_eph::IRNSS  && dt > 86400.0) {
-      ephL->setCheckState(t_eph::outdated);
-      return;
-    }
-  }
-}
-
+    else if  (eph->system() == t_eph::NavIC  && dt > 86400.0) {
+      ephL->setCheckState(t_eph::outdated);
+      return;
+    }
+  }
+}
+
Index: trunk/BNC/src/bncmain.cpp
===================================================================
--- trunk/BNC/src/bncmain.cpp	(revision 10618)
+++ trunk/BNC/src/bncmain.cpp	(revision 10619)
@@ -311,5 +311,5 @@
       "   cmbQzss            {QZSS correction usage [integer number: 0=no,2=yes]}\n"
       "   cmbSbas            {SBAS correction usage [integer number: 0=no,2=yes]}\n"
-      "   cmbIrnss           {IRNSS correction usage [integer number: 0=no,2=yes]}\n"
+      "   cmbNavic           {NavIC correction usage [integer number: 0=no,2=yes]}\n"
       "\n"
       "Upload Corrections Panel keys:\n"
Index: trunk/BNC/src/bncsettings.cpp
===================================================================
--- trunk/BNC/src/bncsettings.cpp	(revision 10618)
+++ trunk/BNC/src/bncsettings.cpp	(revision 10619)
@@ -180,5 +180,5 @@
     setValue_p("cmbQzss",            "0");
     setValue_p("cmbSbas",            "0");
-    setValue_p("cmbIrnss",           "0");
+    setValue_p("cmbNavic",           "0");
 
     // Upload (clk)
Index: trunk/BNC/src/bncutils.cpp
===================================================================
--- trunk/BNC/src/bncutils.cpp	(revision 10618)
+++ trunk/BNC/src/bncutils.cpp	(revision 10619)
@@ -290,5 +290,5 @@
   }
   // update interval: up to 24 hours
-  else if (eph->system() == t_eph::IRNSS   && (fabs(dt > 86400.0))) {
+  else if (eph->system() == t_eph::NavIC   && (fabs(dt > 86400.0))) {
     return true;
   }
@@ -852,5 +852,5 @@
       system == t_eph::SBAS||
       system == t_eph::QZSS||
-      system == t_eph::IRNSS) {
+      system == t_eph::NavIC) {
     if ((index >= 0) && (index <= 6)) {
       if (index == 3) {
@@ -897,5 +897,5 @@
       system == t_eph::SBAS ||
       system == t_eph::QZSS ||
-      system == t_eph::IRNSS) {
+      system == t_eph::NavIC) {
 
     if      (accuracy <= 2.40) {
Index: trunk/BNC/src/bncwindow.cpp
===================================================================
--- trunk/BNC/src/bncwindow.cpp	(revision 10618)
+++ trunk/BNC/src/bncwindow.cpp	(revision 10619)
@@ -544,6 +544,6 @@
   _cmbSbasCheckBox = new QCheckBox();
   _cmbSbasCheckBox->setCheckState(Qt::CheckState(settings.value("cmbSbas").toInt()));
-  _cmbIrnssCheckBox = new QCheckBox();
-  _cmbIrnssCheckBox->setCheckState(Qt::CheckState(settings.value("cmbIrnss").toInt()));
+  _cmbNavicCheckBox = new QCheckBox();
+  _cmbNavicCheckBox->setCheckState(Qt::CheckState(settings.value("cmbNavic").toInt()));
 
   connect(_cmbGpsCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotBncTextChanged()));
@@ -553,5 +553,5 @@
   connect(_cmbQzssCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotBncTextChanged()));
   connect(_cmbSbasCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotBncTextChanged()));
-  connect(_cmbIrnssCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotBncTextChanged()));
+  connect(_cmbNavicCheckBox, SIGNAL(stateChanged(int)), this, SLOT(slotBncTextChanged()));
 
   _cmbBsxFile      = new qtFileChooser(0, qtFileChooser::File);
@@ -1328,6 +1328,6 @@
   cmbLayout->addWidget(_cmbSbasCheckBox,                                         6, 15);
 
-  cmbLayout->addWidget(new QLabel("IRNSS"),                                      7, 14);
-  cmbLayout->addWidget(_cmbIrnssCheckBox,                                        7, 15);
+  cmbLayout->addWidget(new QLabel("NavIC"),                                      7, 14);
+  cmbLayout->addWidget(_cmbNavicCheckBox,                                        7, 15);
   cmbLayout->setRowStretch(9, 999);
 
@@ -1428,5 +1428,5 @@
   _rnxFileCheckBox->setWhatsThis(tr("<p>Tick check box 'Skeleton mandatory' in case you want that RINEX files are only produced if skeleton files are available for BNC. If no skeleton file is available for a particular source then no RINEX Observation file will be produced from the affected stream.</p><p>Note that a skeleton file contains RINEX header information such as receiver and antenna types. In case of stream conversion to RINEX Version 3, a skeleton file should also contain information on potentially available observation types. A missing skeleton file will therefore enforce BNC to only save a default set of RINEX 3 observation types. <i>[key: rnxOnlyWithSKL]</i></p>"));
   _rnxScrpLineEdit->setWhatsThis(tr("<p>Whenever a RINEX Observation file is finally saved, you may want to compress, copy or upload it immediately, for example via FTP. BNC allows you to execute a script/batch file to carry out such operation.</p><p>Specify the full path of a script or batch file. BNC will pass the full RINEX Observation file path to the script as command line parameter (%1 on Windows systems, $1 on Unix/Linux/Mac systems). <i>[key: rnxScript]</i></p>"));
-  _rnxV2Priority->setWhatsThis(tr("<p>Specify a priority list of characters defining signal attributes as defined in RINEX Version 3. Priorities will be used to map observations with RINEX Version 3 attributes from incoming streams to Version 2. The underscore character '_' stands for undefined attributes. A question mark '?' can be used as wildcard which represents any one character.</p><p>Signal priorities can be specified as equal for all systems, as system specific or as system and freq. specific. For example: </li><ul><li>'CWPX_?' (General signal priorities valid for all GNSS) </li><li>'I:ABCX' (System specific signal priorities for IRNSS) </li><li>'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX' (System and frequency specific signal priorities) </li></ul>Default is the following priority list 'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX R:46&ABX E:16&BCXZ E:578&IQX J:1&SLXCZ J:26&SLX J:5&IQX C:267&IQX C:18&DPX I:ABCX S:1&C S:5&IQX'. <i>[key: rnxV2Priority]</i></p>"));
+  _rnxV2Priority->setWhatsThis(tr("<p>Specify a priority list of characters defining signal attributes as defined in RINEX Version 3. Priorities will be used to map observations with RINEX Version 3 attributes from incoming streams to Version 2. The underscore character '_' stands for undefined attributes. A question mark '?' can be used as wildcard which represents any one character.</p><p>Signal priorities can be specified as equal for all systems, as system specific or as system and freq. specific. For example: </li><ul><li>'CWPX_?' (General signal priorities valid for all GNSS) </li><li>'I:ABCX' (System specific signal priorities for NavIC) </li><li>'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX' (System and frequency specific signal priorities) </li></ul>Default is the following priority list 'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX R:46&ABX E:16&BCXZ E:578&IQX J:1&SLXCZ J:26&SLX J:5&IQX C:267&IQX C:18&DPX I:ABCX S:1&C S:5&IQX'. <i>[key: rnxV2Priority]</i></p>"));
   _rnxVersComboBox->setWhatsThis(tr("<p>Select the format for RINEX Observation files. <i>[key: rnxVersion]</i></p>"));
 
@@ -1619,5 +1619,5 @@
   _cmbQzssCheckBox->setWhatsThis(tr("<p>QZSS clock corrections shall be combined; QZSS Broadcast ephemeris and corrections are required. <i>[key: cmbQzss]</i></p>"));
   _cmbSbasCheckBox->setWhatsThis(tr("<p>SBAS clock corrections shall be combined; SBAS Broadcast ephemeris and corrections are required. <i>[key: cmbSbas]</i></p>"));
-  _cmbIrnssCheckBox->setWhatsThis(tr("<p>IRNSS clock corrections shall be combined; IRNSS Broadcast ephemeris and corrections are required. <i>[key: cmbIrnss]</i></p>"));
+  _cmbNavicCheckBox->setWhatsThis(tr("<p>NavIC clock corrections shall be combined; NavIC Broadcast ephemeris and corrections are required. <i>[key: cmbNavic]</i></p>"));
   _cmbBsxFile->setWhatsThis(tr("<p> Specify a Bias SINEX File that will be used to add satellite code biases to the combined clocks. <i>[key: cmbBsxFile]</i></p>"));
 
@@ -1778,5 +1778,5 @@
   delete _cmbQzssCheckBox;
   delete _cmbSbasCheckBox;
-  delete _cmbIrnssCheckBox;
+  delete _cmbNavicCheckBox;
   delete _cmbBsxFile;
   _uploadEphTable->deleteLater();
@@ -2271,5 +2271,5 @@
   settings.setValue("cmbQzss",            _cmbQzssCheckBox->checkState());
   settings.setValue("cmbSbas",            _cmbSbasCheckBox->checkState());
-  settings.setValue("cmbIrnss",           _cmbIrnssCheckBox->checkState());
+  settings.setValue("cmbNavic",           _cmbNavicCheckBox->checkState());
   settings.setValue("cmbBsxFile",         _cmbBsxFile->fileName());
 
@@ -2806,5 +2806,5 @@
       enableWidget(true, _cmbQzssCheckBox);
       enableWidget(true, _cmbSbasCheckBox);
-      enableWidget(true, _cmbIrnssCheckBox);
+      enableWidget(true, _cmbNavicCheckBox);
       enableWidget(true, _cmbBsxFile);
     }
@@ -2821,5 +2821,5 @@
       enableWidget(false, _cmbQzssCheckBox);
       enableWidget(false, _cmbSbasCheckBox);
-      enableWidget(false, _cmbIrnssCheckBox);
+      enableWidget(false, _cmbNavicCheckBox);
       enableWidget(false, _cmbBsxFile);
     }
Index: trunk/BNC/src/bncwindow.h
===================================================================
--- trunk/BNC/src/bncwindow.h	(revision 10618)
+++ trunk/BNC/src/bncwindow.h	(revision 10619)
@@ -229,5 +229,5 @@
     QCheckBox*     _cmbQzssCheckBox;
     QCheckBox*     _cmbSbasCheckBox;
-    QCheckBox*     _cmbIrnssCheckBox;
+    QCheckBox*     _cmbNavicCheckBox;
     qtFileChooser* _cmbBsxFile;
 
Index: trunk/BNC/src/combination/bncbiassnx.cpp
===================================================================
--- trunk/BNC/src/combination/bncbiassnx.cpp	(revision 10618)
+++ trunk/BNC/src/combination/bncbiassnx.cpp	(revision 10619)
@@ -56,5 +56,5 @@
   _useGnss['J'] = (Qt::CheckState(settings.value("cmbQzss").toInt()) == Qt::Checked) ? true : false;
   _useGnss['S'] = (Qt::CheckState(settings.value("cmbSbas").toInt()) == Qt::Checked) ? true : false;
-  _useGnss['I'] = (Qt::CheckState(settings.value("cmbIrnss").toInt()) == Qt::Checked) ? true : false;
+  _useGnss['I'] = (Qt::CheckState(settings.value("cmbNavic").toInt()) == Qt::Checked) ? true : false;
 }
 
Index: trunk/BNC/src/combination/bnccomb.cpp
===================================================================
--- trunk/BNC/src/combination/bnccomb.cpp	(revision 10618)
+++ trunk/BNC/src/combination/bnccomb.cpp	(revision 10619)
@@ -162,7 +162,7 @@
     _masterMissingEpochs['S'] = 0;
   }
-  _useIrnss = (Qt::CheckState(settings.value("cmbIrnss").toInt()) == Qt::Checked) ? true : false;
-  if (_useIrnss) {
-    _cmbSysPrn['I'] = t_prn::MAXPRN_IRNSS;
+  _useNavic = (Qt::CheckState(settings.value("cmbNavic").toInt()) == Qt::Checked) ? true : false;
+  if (_useNavic) {
+    _cmbSysPrn['I'] = t_prn::MAXPRN_NavIC;
     _masterMissingEpochs['I'] = 0;
   }
Index: trunk/BNC/src/combination/bnccomb.h
===================================================================
--- trunk/BNC/src/combination/bnccomb.h	(revision 10618)
+++ trunk/BNC/src/combination/bnccomb.h	(revision 10619)
@@ -282,5 +282,5 @@
   bool                                       _useQzss;
   bool                                       _useSbas;
-  bool                                       _useIrnss;
+  bool                                       _useNavic;
   bool                                       _running;
 };
Index: trunk/BNC/src/ephemeris.cpp
===================================================================
--- trunk/BNC/src/ephemeris.cpp	(revision 10618)
+++ trunk/BNC/src/ephemeris.cpp	(revision 10619)
@@ -430,5 +430,5 @@
     // BROADCAST ORBIT - 5
     // =====================
-    else if (iLine == 5 && system() != t_eph::IRNSS) {
+    else if (iLine == 5 && system() != t_eph::NavIC) {
       if (type() == t_eph::CNAV ||
           type() == t_eph::CNV2) {
@@ -450,5 +450,5 @@
         }
       }
-    } else if (iLine == 5 && system() == t_eph::IRNSS) {
+    } else if (iLine == 5 && system() == t_eph::NavIC) {
       if (type() == t_eph::LNAV) {
         if (   readDbl(line, pos[0], fieldLen, _IDOT)
@@ -470,5 +470,5 @@
     // BROADCAST ORBIT - 6
     // =====================
-    else if (iLine == 6 && system() != t_eph::IRNSS) {
+    else if (iLine == 6 && system() != t_eph::NavIC) {
       if (type() == t_eph::CNAV ||
           type() == t_eph::CNV2) {
@@ -490,5 +490,5 @@
       }
     }
-    else if (iLine == 6 && system() == t_eph::IRNSS) {
+    else if (iLine == 6 && system() == t_eph::NavIC) {
       if (type() == t_eph::LNAV) {
         if (   readDbl(line, pos[0], fieldLen, _ura)
@@ -520,5 +520,5 @@
           return;
         }
-        if (system() != t_eph::IRNSS) {
+        if (system() != t_eph::NavIC) {
           double fitIntervalRnx;
           if (readDbl(line, pos[1], fieldLen, fitIntervalRnx)) {
@@ -812,5 +812,5 @@
   // BROADCAST ORBIT - 5
   // =====================
-  if (system() != t_eph::IRNSS) {
+  if (system() != t_eph::NavIC) {
     if (type() == t_eph::CNAV ||
         type() == t_eph::CNV2) {
@@ -853,5 +853,5 @@
   // BROADCAST ORBIT - 6
   // =====================
-  if (system() != t_eph::IRNSS) {
+  if (system() != t_eph::NavIC) {
     if (type() == t_eph::CNAV ||
         type() == t_eph::CNV2) {
@@ -912,5 +912,5 @@
     }
     // fitInterval
-    if (system() == t_eph::IRNSS) {
+    if (system() == t_eph::NavIC) {
       out
           << QString(fmt)
Index: trunk/BNC/src/reqcdlg.cpp
===================================================================
--- trunk/BNC/src/reqcdlg.cpp	(revision 10618)
+++ trunk/BNC/src/reqcdlg.cpp	(revision 10619)
@@ -242,5 +242,5 @@
   _reqcRnxVersion->setWhatsThis(tr("<p>Select version number of emerging new RINEX file.</p><p>Note the following:</p><p>When converting <u>RINEX Version 2 to Version 3 </u>Observation files, the tracking mode or channel information (signal attribute, see RINEX Version 3 documentation) in the (last out of the three characters) observation code is left blank if unknown.</p><p>When converting <u>RINEX Version 3 to Version 2</u>, the mapping of observations follows a 'Signal priority list' with signal attributes as defined in RINEX Version 3. <i>[key: reqcRnxVersion]</i></p>"));
   _reqcSampling->setWhatsThis(tr("<p>Select sampling rate of emerging new RINEX Observation file. <i>[key: reqcSampling]</i></p>"));
-  _reqcV2Priority->setWhatsThis(tr("<p>Specify a priority list of characters defining signal attributes as defined in RINEX Version 3. Priorities will be used to map observations with RINEX Version 3 attributes from incoming streams to Version 2. The underscore character '_' stands for undefined attributes. A question mark '?' can be used as wildcard which represents any one character.</p><p>Signal priorities can be specified as equal for all systems, as system specific or as system and freq. specific. For example: </li><ul><li>'CWPX_?' (General signal priorities valid for all GNSS) </li><li>'C:IQX I:ABCX' (System specific signal priorities for BDS and IRNSS) </li><li>'G:12&PWCSLXYN G:5&IQX R:12&PC R:3&IQX' (System and frequency specific signal priorities) </li></ul>Default is the following priority list 'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX R:46&ABX E:16&BCXZ E:578&IQX J:1&SLXCZ J:26&SLX J:5&IQX C:267&IQX C:18&DPX I:ABCX S:1&C S:5&IQX'. <i>[key: reqcV2Priority]</i></p>"));
+  _reqcV2Priority->setWhatsThis(tr("<p>Specify a priority list of characters defining signal attributes as defined in RINEX Version 3. Priorities will be used to map observations with RINEX Version 3 attributes from incoming streams to Version 2. The underscore character '_' stands for undefined attributes. A question mark '?' can be used as wildcard which represents any one character.</p><p>Signal priorities can be specified as equal for all systems, as system specific or as system and freq. specific. For example: </li><ul><li>'CWPX_?' (General signal priorities valid for all GNSS) </li><li>'C:IQX I:ABCX' (System specific signal priorities for BDS and NavIC) </li><li>'G:12&PWCSLXYN G:5&IQX R:12&PC R:3&IQX' (System and frequency specific signal priorities) </li></ul>Default is the following priority list 'G:12&PWCSLX G:5&IQX R:12&PC R:3&IQX R:46&ABX E:16&BCXZ E:578&IQX J:1&SLXCZ J:26&SLX J:5&IQX C:267&IQX C:18&DPX I:ABCX S:1&C S:5&IQX'. <i>[key: reqcV2Priority]</i></p>"));
   _reqcStartDateTime->setWhatsThis(tr("<p>Specify begin of emerging new RINEX Observation file. <i>[key: reqcStartDateTime]</i></p>"));
   _reqcEndDateTime->setWhatsThis(tr("<p>Specify end of emerging new RINEX Observation file. <i>[key: reqcEndDateTime]</i></p>"));
Index: trunk/BNC/src/rinex/reqcedit.cpp
===================================================================
--- trunk/BNC/src/rinex/reqcedit.cpp	(revision 10618)
+++ trunk/BNC/src/rinex/reqcedit.cpp	(revision 10619)
@@ -613,6 +613,6 @@
         haveGnss[t_eph::QZSS] = true;
         break;
-      case t_eph::IRNSS:
-        haveGnss[t_eph::IRNSS] = true;
+      case t_eph::NavIC:
+        haveGnss[t_eph::NavIC] = true;
         break;
       case t_eph::SBAS:
@@ -779,5 +779,5 @@
         ephs.append(new t_ephBDS(*dynamic_cast<t_ephBDS*>(eph)));
       }
-      else if (eph->system() == t_eph::IRNSS) {
+      else if (eph->system() == t_eph::NavIC) {
         ephs.append(new t_ephGPS(*dynamic_cast<t_ephGPS*>(eph)));
       }
Index: trunk/BNC/src/rinex/rnxnavfile.cpp
===================================================================
--- trunk/BNC/src/rinex/rnxnavfile.cpp	(revision 10618)
+++ trunk/BNC/src/rinex/rnxnavfile.cpp	(revision 10619)
@@ -411,6 +411,6 @@
         fmt.append("%1           N: GNSS NAV DATA    C: BDS");
         break;
-      case t_eph::IRNSS:
-        fmt.append("%1           N: GNSS NAV DATA    I: IRNSS");
+      case t_eph::NavIC:
+        fmt.append("%1           N: GNSS NAV DATA    I: NavIC");
         break;
       case t_eph::SBAS:
Index: trunk/BNC/src/rinex/rnxobsfile.cpp
===================================================================
--- trunk/BNC/src/rinex/rnxobsfile.cpp	(revision 10618)
+++ trunk/BNC/src/rinex/rnxobsfile.cpp	(revision 10619)
@@ -1371,5 +1371,5 @@
     const t_rnxSat& rnxSat = epo->rnxSat[ii];
     if (_header._obsTypes[rnxSat.prn.system()].size() > 0) {
-      if (_header.version() < 3.0) { // exclude new GNSS such as BDS, QZSS, IRNSS, etc.
+      if (_header.version() < 3.0) { // exclude new GNSS such as BDS, QZSS, NavIC, etc.
           if (rnxSat.prn.system() != 'G' && rnxSat.prn.system() != 'R' &&
               rnxSat.prn.system() != 'E' && rnxSat.prn.system() != 'S' &&
Index: trunk/BNC/src/rinex/rnxobsfile.h
===================================================================
--- trunk/BNC/src/rinex/rnxobsfile.h	(revision 10618)
+++ trunk/BNC/src/rinex/rnxobsfile.h	(revision 10619)
@@ -237,5 +237,5 @@
       const t_rnxSat& rnxSat = epo->rnxSat[ii];
       if (header._obsTypes[rnxSat.prn.system()].size() > 0) {
-        if (header.version() < 3.0) { // exclude new GNSS such as BDS, QZSS, IRNSS, etc.
+        if (header.version() < 3.0) { // exclude new GNSS such as BDS, QZSS, NavIC, etc.
             if (rnxSat.prn.system() != 'G' && rnxSat.prn.system() != 'R' &&
                 rnxSat.prn.system() != 'E' && rnxSat.prn.system() != 'S' ) {
Index: trunk/BNC/src/t_prn.h
===================================================================
--- trunk/BNC/src/t_prn.h	(revision 10618)
+++ trunk/BNC/src/t_prn.h	(revision 10619)
@@ -12,7 +12,7 @@
   static const unsigned MAXPRN_SBAS    = 38;
   static const unsigned MAXPRN_BDS     = 65;
-  static const unsigned MAXPRN_IRNSS   = 20;
+  static const unsigned MAXPRN_NavIC   = 20;
   static const unsigned MAXPRN = MAXPRN_GPS + MAXPRN_GLONASS + MAXPRN_GALILEO
-      + MAXPRN_QZSS + MAXPRN_SBAS + MAXPRN_BDS + MAXPRN_IRNSS;
+      + MAXPRN_QZSS + MAXPRN_SBAS + MAXPRN_BDS + MAXPRN_NavIC;
 
   t_prn() :
Index: trunk/BNC/src/upload/bncephuploadcaster.cpp
===================================================================
--- trunk/BNC/src/upload/bncephuploadcaster.cpp	(revision 10618)
+++ trunk/BNC/src/upload/bncephuploadcaster.cpp	(revision 10619)
@@ -121,5 +121,5 @@
           }
         }
-        else if (ephGPS && ephGPS->system() == t_eph::IRNSS && (system == "ALL" || system.contains('I'))) {
+        else if (ephGPS && ephGPS->system() == t_eph::NavIC && (system == "ALL" || system.contains('I'))) {
           if (fabs(dt < 86400.0)) {
             size = t_ephEncoder::RTCM3(*ephGPS, Array);

Index: trunk/BNC/src/RTCM3/RTCM3Decoder.cpp
===================================================================
--- trunk/BNC/src/RTCM3/RTCM3Decoder.cpp	(revision 10618)
+++ trunk/BNC/src/RTCM3/RTCM3Decoder.cpp	(revision 10619)
@@ -425,5 +425,5 @@
     };
 
 /** MSM signal types for IRNSS */
 static struct CodeData irn[RTCM3_MSM_NUMSIG] = {
         {0.0, 0},
@@ -434,19 +434,19 @@
         {0.0, 0},
         {0.0, 0},
-        {IRNSS_WAVELENGTH_S, "9A"},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {0.0, 0},
-        {IRNSS_WAVELENGTH_L5, "5A"},
+        {NavIC_WAVELENGTH_S, "9A"},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {0.0, 0},
+        {NavIC_WAVELENGTH_L5, "5A"},
         {0.0, 0},
         {0.0, 0},
@@ -1467,5 +1467,5 @@
 //
 ////////////////////////////////////////////////////////////////////////////
-bool RTCM3Decoder::DecodeIRNSSEphemeris(unsigned char* data, int size) {
+bool RTCM3Decoder::DecodeNavICEphemeris(unsigned char* data, int size) {
   bool decoded = false;
 
@@ -2267,5 +2267,5 @@
             break;
           case 1041:
-            if (DecodeIRNSSEphemeris(_Message, _BlockSize))
+            if (DecodeNavICEphemeris(_Message, _BlockSize))
               decoded = true;
             break;
@@ -425,5 +425,5 @@
     };
 
-/** MSM signal types for IRNSS */
+/** MSM signal types for NavIC */
 static struct CodeData irn[RTCM3_MSM_NUMSIG] = {
         {0.0, 0},
Index: trunk/BNC/src/ephemeris.h
===================================================================
--- trunk/BNC/src/ephemeris.h	(revision 10618)
+++ trunk/BNC/src/ephemeris.h	(revision 10619)
@@ -16,5 +16,5 @@
 class t_eph {
  public:
-  enum e_system {unknown, GPS, QZSS, GLONASS, Galileo, SBAS, BDS, IRNSS};
+  enum e_system {unknown, GPS, QZSS, GLONASS, Galileo, SBAS, BDS, NavIC};
   enum e_checkState {unchecked, ok, bad, outdated, unhealthy};
   enum e_type {undefined, LNAV, FDMA, FDMA_M, FNAV, INAV, D1, D2, SBASL1, CNAV, CNV1, CNV2, CNV3, L1NV, L1OC, L3OC};
@@ -136,5 +136,5 @@
         return t_eph::QZSS;
       case 'I':
-        return t_eph::IRNSS;
+        return t_eph::NavIC;
     };
     return t_eph::GPS;
@@ -152,5 +152,5 @@
   double  _clock_driftrate; // [s/s^2]
 
-  double  _IODE;            // IODEC in case of IRNSS
+  double  _IODE;            // IODEC in case of NavIC
   double  _Crs;             // [m]
   double  _Delta_n;         // [rad/s]
@@ -173,15 +173,15 @@
 
   double  _IDOT;            // [rad/s]
-  double  _L2Codes;         // Codes on L2 channel  (not valid for IRNSS)
+  double  _L2Codes;         // Codes on L2 channel  (not valid for NavIC)
   double  _TOEweek;         // GPS week # to go with TOE, cont. number, not mode 1024
-  double  _L2PFlag;         // L2 P data flag (not valid for IRNSS and QZSS)
+  double  _L2PFlag;         // L2 P data flag (not valid for NavIC and QZSS)
 
   mutable double  _ura;     // SV accuracy [m]
   double  _health;          // SV health
   double  _TGD;             // [s]
-  double  _IODC;            // (not valid for IRNSS)
+  double  _IODC;            // (not valid for NavIC)
 
   double  _TOT;             // Transmission time
-  double  _fitInterval;     // Fit interval in hours (not valid for IRNSS)
+  double  _fitInterval;     // Fit interval in hours (not valid for NavIC)
 
   double  _ADOT;            // [m/s]
@@ -202,5 +202,5 @@
   double _ISC_L1Cp;         // [s]
 
-  double _RSF;              // [-] Reference Signal Flag for IRNSS
+  double _RSF;              // [-] Reference Signal Flag for NavIC
   double _ISC_S;            // [s]
   double _ISC_L1D;          // [s]